%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script to generate as of t anticipated alternative interest paths bet-
% ween t through T=t+h for some h>0 using the trinity NK model. The paths
% are generated around the steady state as described in the notes.
%
% Remark #1: The Model is coded up for 12 leads of policy shocks in the
%            policy rule and if the ZLB binds for more periods then one
%            needs to add more leads in the BabySigma model file.
%
% Written and last modified by Jesper Lind 2009-02-19
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%clear all;
%close all;
ConvCrit=1e-12;
load AltIntRatePath;%Alternative interest rate path under consideration
ParseModel=0;%if 1, then parse model, if 0 then use already parsed model in *_aim_matrices script file

% if WorkWithSoemod == 1;
%    parm_soemod1;  %declare parameters
%    solve_soemod1; %Solves model and compute decision rules, loads AIM information
% elseif WorkWithSoemod == 2;
%    parm_soemod2;  %declare parameters
%    solve_soemod2; %Solves model and compute decision rules, loads AIM information
% else error('WorkWithSoemod must take either value of 1 or 2');
% end;

TT=T;%number of periods ahead to compute IRFs

AltIntRatePath = -AltIntRatePath./4;%finding policy shocks that produces the negative of the quarterly path
IndVec = find(AltIntRatePath>0);
StartPeriod=IndVec(1);
ActIndicator=zeros(length(AltIntRatePath),1);
ActIndicator(StartPeriod)=1;

RSLoc  = strmatch('rs',cellstr(endog_),'exact');%place in AIM solution
IrLoc  = find(PickVars==strmatch('rs',cellstr(endog_),'exact'));%place in simvar

Shock0 = strmatch('errshk0',cellstr(endog_),'exact')-sum(eqtype_);%nendog;
Shock20= strmatch('errshk20',cellstr(endog_),'exact')-sum(eqtype_);%nendog;
ShockLoc=[Shock0:1:Shock20];
ModelProjOld= zeros(TT,6);
%figure
for t=StartPeriod:length(AltIntRatePath);%Looping forward until finding a solution that respects the ZLB
    
    %Step 1: Find the shocks that are needed to impose the alternative
    %interest rate path to period t, assuming that we hit the ZLB in the
    %first period (this conjecture is verified if the forecast in t+1 is negative)
    [Shocks,ShockLoci] = FindShocksAIM(cofb,scof,RSLoc,AltIntRatePath(1:t),ShockLoc,ActIndicator(1:t),eqtype_,endog_);
    
    %Step 2: Given these shocks, simulate the model and compute impulse
    %response functions to the policy shock, underlying demand shock also
    %included
    [simvar,zzAIM] = SimulateModelAIM(cofb,scof,zzInit,[ShockSizeOS;Shocks],[ShockLocOS;ShockLoci],TT,eqtype_,endog_,PickVars);
    simvar=simvar.*(ones(T,1)*ScalVec)+ones(T,1)*MeanVec;%scaling and adding mean
    
    if StartPeriod>1 & ActIndicator(StartPeriod-1)==0;
        if min(simvar(1:StartPeriod-1,IrLoc))<-ConvCrit;%needs to expand ActIndicator backwards to take care of negative values
            IndVec=find(simvar(1:StartPeriod-1,IrLoc)<-ConvCrit);
            ActIndicator(IndVec)=1;
            StartPeriod=StartPeriod-1;
            [Shocks,ShockLoci] = FindShocksAIM(cofb,scof,RSLoc,AltIntRatePath(1:t),ShockLoc,ActIndicator(1:t),eqtype_,endog_);
            [simvar,zzAIM] = SimulateModelAIM(cofb,scof,zzInit,[ShockSizeOS;Shocks],[ShockLocOS;ShockLoci],TT,eqtype_,endog_,PickVars);
            simvar=simvar.*(ones(T,1)*ScalVec)+ones(T,1)*MeanVec;%scaling and adding mean
        end;
    end;
    %Shocks'
    ModelProj  =simvar;
    %plot([ModelProjOld(:,IrLoc) ModelProj(:,IrLoc)]);pause(2);%plotting interest rate forecast conditional on hitting the ZLB upto time t
    ModelProjOld=ModelProj;
    if min(ModelProj(t+1:end,IrLoc))<-ConvCrit;
        %disp(' ');
        %disp('We are not done, need to impose ZLB one more period');pause(0.2);
        %disp(' ');
        ActIndicator(t+1)=1;
    else;
        %disp(' ');
        %disp('We are done, the ZLB solution is available in matrix ModelProj!')
        %disp('We are done, add factors are available in matrix Shocks!')
        %ShockLoc = ShockLoci;
        %T=t;%Number of periods needed to impose the ZLB
        break
    end;
end;

%testing if the interest rate path satisfies the max operator

SysPart = gam_rs*[0 zzAIM(RSLoc,1:end-1)] + (1-gam_rs)*( gam_dpq*zzAIM(DPQLoc,:) +  ...
    gam_xgap*zzAIM(XGAPLoc,:) );

disp(' ');
disp('actual, systematic part, max(-1,SysPart) and the policy shocks')
disp(num2str([zzAIM(RSLoc,1:min([21 T]))' SysPart(1:min([21 T]))' max(-1,SysPart(1:min([21 T])))' zzAIM(MPSHKLoc,1:min([21 T]))']));
