function [simvarAIM,zzAIM] = SimulateModelAIM(cofb,scof,zz_0,std_err,jj,T,eqtype_,endog_,PickVars);
   
simvarAIM = [];
   
% NOTE: This procedure generates the actual levels for the variables that have been
% scaled by the unitroot technology shock z(t) in the matrix simvar, whereas the
% separate variables x in the output list (e.g. outp) are x(t)/z(t-j).
% Modified by JL 2002-09-19.
       
% This description comes from Jesper's 9/7/01 code
% This procedure simulates the following system 
%    z(t) = A*z(t-1) + B*s(t),
%    s(t) = P*s(t-1) + e(t).
% for a given sequence, 
%    e(1),...,e(T)
% 
% the simulations are done subject to z(0)=s(0)=0,
% this program is written inefficiently, with a do-loop
%
% It returns a matrix Txk with k variables for T
% observations.

nshk=length(find(eqtype_==0)); % # exogenous shocks
ntot=size(endog_,1);
nendog = ntot-nshk;
Amat = full(cofb);
bstar=inv(full(scof(:,ntot+1:2*ntot)));
Bmat=bstar(:,nendog+1:nendog+nshk);

%Simulate zz(t) = [z(t) theta(t) 1 e(t)]
% compute response to shock jj 
e=zeros(nshk,T);
zzAIM=zeros(ntot,T);%see definition above
e(jj,1:size(std_err,2))=std_err;
zzAIM(:,1) = Amat*zz_0+Bmat*e(:,1);
for t=2:T
    zzAIM(:,t) = Amat*zzAIM(:,t-1) + Bmat*e(:,t);
end;

simvarAIM = zzAIM(PickVars,:)'; %size T x nvars
%keyboard;
