%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Figure 12 of April 2014 final version
% Analyzes Different coefficients on the participation gap in Phillips
% Curve (holding reduced form coefficient on unemployment gap constant
% across calibrations)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

T = 40;            %Number of periods to compute impulse
PlotInternal = 1;  %Set of variables to plot, 1 for internal variables, 0 for figures in paper
PlotInLevels = 1;  %if 1, then plot in level space where steady state values in MeanVec are used. If 0, then plot as deviations from SS

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Type and size of shocks to compute
%IRFs for
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

mu1 = .92;
mu2 = 0;
mu3 = .071;
kappap = .000766;
chi = 4;
psip = .975;
gam_dpq= 2;
gam_xgap= 150;
gam_egap = 0;

solv_searchn1;

ShockSizeDom=[-.97*1.19];
ShockSizeFor=[];%0.5*ShockSizeDom;
ShockLocDom = strmatch('errbtar',cellstr(endog_),'exact')-sum(eqtype_);%nendog;
ShockLocFor = [];%strmatch('errconf',cellstr(endog_),'exact')-sum(eqtype_);%nendog;
ShockLocOS  = [ShockLocDom;ShockLocFor];
ShockSizeOS = [ShockSizeDom;ShockSizeFor];

XGAPLoc   = strmatch('xgap',cellstr(endog_),'exact');%nendog;
DPQLoc    = strmatch('dpq',cellstr(endog_),'exact');%nendog;
RSLoc     = strmatch('rs',cellstr(endog_),'exact');%nendog;
RRLoc     = strmatch('rt',cellstr(endog_),'exact');%nendog;
RRPOTLoc  = strmatch('rt_pot',cellstr(endog_),'exact');%nendog;
BTARSHKLoc = strmatch('btarshk',cellstr(endog_),'exact');%nendog;
GOVSHKLoc = strmatch('govshk',cellstr(endog_),'exact');%nendog;
PMARKSHKLoc = strmatch('techshk',cellstr(endog_),'exact');%nendog;
MPSHKLoc  = strmatch('errffr0',cellstr(endog_),'exact');%nendog;
PQLoc   = strmatch('pq',cellstr(endog_),'exact');%nendog;
EGAPLoc   = strmatch('egap',cellstr(endog_),'exact');%nendog;
LFPGAPLoc   = strmatch('lfpgap',cellstr(endog_),'exact');%nendog;


%ibar_apr = ((pibar^4-1)+((1+rbar)^4-1))*100;%steady state nominal interest rate in APR
ibar_apr = 4;

if PlotInternal == 1;%Figures for internal use
   %PickVars = [XGAPLoc DPQLoc RSLoc    RRLoc RRPOTLoc GDPLoc GOVSHKLoc DEBTGLoc     TAXLLoc];%location of variables in simvar
   %ScalVec  = [1       4      4        4     4        1      shrgy     1/4          1 ];%transform variables to APR when suitable
   PickVars = [EGAPLoc LFPGAPLoc RSLoc   DPQLoc XGAPLoc RRPOTLoc];%location of variables in simvar
   ScalVec  = [-1       1      4        4     1/(1-alpha)   4 ];%transform variables to APR when suitable
   
   MeanVec  = [0       0      ibar_apr  2     0      2];%adding steady state means when suitable
   LegNames=char('Unemployment Gap','Participation Gap','Nominal Interest Rate (APR)',...
                 'Inflation','Overall Employment Gap','Potential Real Interest Rate (APR)');
elseif PlotInternal == 0;%draw figures for the paper
   PickVars = [XGAPLoc PQLoc DPQLoc RSLoc    RRLoc RRPOTLoc EGAPLoc     LFPGAPLoc];%location of variables in simvar
   ScalVec  = [1/(1-alpha)       1      4      4        4     4        1          1 ];%transform variables to APR when suitable
   MeanVec  = [0       0      2      ibar_apr 2     2        0  0 ];%adding steady state means when suitable
   LegNames=char('Output Gap','Price Level','Inflation (APR)','Nominal Interest Rate (APR)',...
                 'Real Interest Rate (APR)','Potential Real Interest Rate (APR)',...
                 'Employment Gap','Participation Gap');
else;
   error('Must set PlotInternal to either 0 or 1');
end;

figrows = ceil(sqrt(length(PickVars)));
figcols = floor(sqrt(length(PickVars)));
if figrows*figcols<length(PickVars);
   figrows=figrows+1;
end;


zzInit = zeros(size(cofb,1),1);%vector with initial state, deviations from steady state
[simvar,zzAimOSunc]=SimulateModelAIM(cofb,scof,zzInit,ShockSizeOS,ShockLocOS,T,eqtype_,endog_,PickVars); %Function that compute impulse response functions
simvarOSunc = simvar.*(ones(T,1)*ScalVec)+ones(T,1)*MeanVec;%scaling and adding mean

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step 2: Do same thing as above
% but impose ZLB when computing the
% impulse response functions.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Step 2a: Compute shocks that are needed
%to impose the ZLB for the shocks above.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

AltIntRatePath=simvarOSunc(1:T,find(PickVars==RSLoc));%Potentially negative interest rate paths to be turned into ZLB    
save AltIntRatePath AltIntRatePath ShockLocOS ShockSizeOS zzInit;
simvarOScon=simvarOSunc;%unconstrained responses

if min(min(AltIntRatePath))<-1e-5;
   FindAltIntPathsScriptSlow;%plotting with figures
   IRpath = AltIntRatePath(1:t,:);
   [Shocks,ShockLoc] = FindShocksAIM(cofb,scof,RSLoc,IRpath,ShockLoc,ActIndicator(1:t,:),eqtype_,endog_);
   [simvarPI,zzAimPI]=SimulateModelAIM(cofb,scof,zzInit,Shocks,ShockLoc,T,eqtype_,endog_,PickVars); %Compute impulse response functions for policy interventions
   simvarPI=simvarPI.*(ones(T,1)*ScalVec);%annualizing
   simvarOScon=simvarOScon+simvarPI;%updating simvar (unconstrained response with policy intervention that respects ZLB)
   zzAimOScon = zzAimOSunc+zzAimPI;%total effects of demand shocks under ZLB
end;

%VarNames=char('FFR','FFR*','dCPI','dCPI*','GDP','GDP*');
if PlotInLevels==0;%if 0 then take away means
   simvarOSunc = simvarOSunc-ones(T,1)*MeanVec;
   simvarOScon = simvarOScon-ones(T,1)*MeanVec;
end;

simvarOSunc_xgap = simvarOSunc;
simvarOScon_xgap = simvarOScon;


% Now Compute IRFS assuming non-participants affect wages as much as participants

chi = 1;
psi0 =  chi + alpha + (1-alpha)*sigma_hat; 
kappap_new = sparm/psi0;
psip = (1/(2*beta))*((1+ kappap_new+ beta) - ((1 + kappap_new+beta)^2 - 4*beta)^0.5)

chi_large = chi;
psip_large = psip;


% the following parameters are reported in the paper, but not used directly
% in program (inferred from values we have set for mu1, mu3, lfbar, and
% 1-ubar
% 
phim_large = mu3/(1-ubar);     % phim is the response of participation gap to unemp rate reported in paper
sigmag_large = (1+chi)*(1-mu1)/(mu3*(lfbar/lhbar));  % curvature parameter in utility function over home production
phig_prime = mu1/(1-mu1);
chi0_large = (1-alpha)*(lfbar*hbar)^(-alpha)*lambar*hbar^(-chi);
gammag_large = (chi/(1+chi))*((1-lfbar)^sigmag)*chi0*hbar^(1+chi);
qlbar = gammag*lhbar^(-sigmag);
phig_large = phig_prime/(lambar*sigmag*(lfbar/lhbar));




solv_searchn1;

%kappap = .03/psi0;
%psip = (1/(2*beta))*((1+ kappap+ beta) - ((1 + kappap+beta)^2 - 4*beta)^0.5)
%psi1 = 0.15*psi0;


zzInit = zeros(size(cofb,1),1);%vector with initial state, deviations from steady state
[simvar,zzAimOSunc]=SimulateModelAIM(cofb,scof,zzInit,ShockSizeOS,ShockLocOS,T,eqtype_,endog_,PickVars); %Function that compute impulse response functions
simvarOSunc = simvar.*(ones(T,1)*ScalVec)+ones(T,1)*MeanVec;%scaling and adding mean


AltIntRatePath=simvarOSunc(1:T,find(PickVars==RSLoc));%Potentially negative interest rate paths to be turned into ZLB    
save AltIntRatePath AltIntRatePath ShockLocOS ShockSizeOS zzInit;
simvarOScon=simvarOSunc;%unconstrained responses

if min(min(AltIntRatePath))<-1e-5;
   FindAltIntPathsScriptSlow;%plotting with figures
   IRpath = AltIntRatePath(1:t,:);
   [Shocks,ShockLoc] = FindShocksAIM(cofb,scof,RSLoc,IRpath,ShockLoc,ActIndicator(1:t,:),eqtype_,endog_);
   [simvarPI,zzAimPI]=SimulateModelAIM(cofb,scof,zzInit,Shocks,ShockLoc,T,eqtype_,endog_,PickVars); %Compute impulse response functions for policy interventions
   simvarPI=simvarPI.*(ones(T,1)*ScalVec);%annualizing
   simvarOScon=simvarOScon+simvarPI;%updating simvar (unconstrained response with policy intervention that respects ZLB)
   zzAimOScon = zzAimOSunc+zzAimPI;%total effects of demand shocks under ZLB
end;

%VarNames=char('FFR','FFR*','dCPI','dCPI*','GDP','GDP*');
if PlotInLevels==0;%if 0 then take away means
   simvarOSunc = simvarOSunc-ones(T,1)*MeanVec;
   simvarOScon = simvarOScon-ones(T,1)*MeanVec;
end;

simvarOSunc_dpq = simvarOSunc;
simvarOScon_dpq = simvarOScon;


% Now assume nonparticipants have no effect on wages

chi = 100;
psi0 =  chi + alpha + (1-alpha)*sigma_hat; 
kappap_new = sparm/psi0;
psip = (1/(2*beta))*((1+ kappap_new+ beta) - ((1 + kappap_new+beta)^2 - 4*beta)^0.5)

% the following parameters are reported in the paper, but not used directly
% in program (inferred from values we have set for mu1, mu3, lfbar, and
% 1-ubar
% 

chi_tiny = chi;
psip_tiny = psip;
phim_tiny = mu3/(1-ubar);     % phim is the response of participation gap to unemp rate reported in paper
sigmag_tiny = (1+chi)*(1-mu1)/(mu3*(lfbar/lhbar));  % curvature parameter in utility function over home production
phig_prime = mu1/(1-mu1);
chi0_tiny = (1-alpha)*(lfbar*hbar)^(-alpha)*lambar*hbar^(-chi);
gammag_tiny = (chi/(1+chi))*((1-lfbar)^sigmag)*chi0*hbar^(1+chi);
qlbar = gammag*lhbar^(-sigmag);
phig_tiny = phig_prime/(lambar*sigmag*(lfbar/lhbar));



solv_searchn1;

zzInit = zeros(size(cofb,1),1);%vector with initial state, deviations from steady state
[simvar,zzAimOSunc]=SimulateModelAIM(cofb,scof,zzInit,ShockSizeOS,ShockLocOS,T,eqtype_,endog_,PickVars); %Function that compute impulse response functions
simvarOSunc = simvar.*(ones(T,1)*ScalVec)+ones(T,1)*MeanVec;%scaling and adding mean


AltIntRatePath=simvarOSunc(1:T,find(PickVars==RSLoc));%Potentially negative interest rate paths to be turned into ZLB    
save AltIntRatePath AltIntRatePath ShockLocOS ShockSizeOS zzInit;
simvarOScon=simvarOSunc;%unconstrained responses

if min(min(AltIntRatePath))<-1e-5;
   FindAltIntPathsScriptSlow;%plotting with figures
   IRpath = AltIntRatePath(1:t,:);
   [Shocks,ShockLoc] = FindShocksAIM(cofb,scof,RSLoc,IRpath,ShockLoc,ActIndicator(1:t,:),eqtype_,endog_);
   [simvarPI,zzAimPI]=SimulateModelAIM(cofb,scof,zzInit,Shocks,ShockLoc,T,eqtype_,endog_,PickVars); %Compute impulse response functions for policy interventions
   simvarPI=simvarPI.*(ones(T,1)*ScalVec);%annualizing
   simvarOScon=simvarOScon+simvarPI;%updating simvar (unconstrained response with policy intervention that respects ZLB)
   zzAimOScon = zzAimOSunc+zzAimPI;%total effects of demand shocks under ZLB
end;

%VarNames=char('FFR','FFR*','dCPI','dCPI*','GDP','GDP*');
if PlotInLevels==0;%if 0 then take away means
   simvarOSunc = simvarOSunc-ones(T,1)*MeanVec;
   simvarOScon = simvarOScon-ones(T,1)*MeanVec;
end;

simvarOSunc_egap = simvarOSunc;
simvarOScon_egap = simvarOScon;


close all;

TT=1:T;
titles = {['Figure 12: Inflation Responsiveness to Participation Gap']};    

for nfig=1:size(simvar,2);
    subplot(figrows,figcols,nfig)
    h1=plot(TT,simvarOScon_dpq(:,nfig)',TT,simvarOScon_xgap(:,nfig)',TT,simvarOScon_egap(:,nfig)');
    set(h1,'linewidth',3,{'linestyle'},{':';'-';'-.'},{'color'},{'r';'k';'b'});
    text('String',LegNames(nfig,:),'Units','normalized', ...
         'Position',[0.5 1.08],...
         'FontSize',10,'FontWeight','bold','HorizontalAlignment','center');
      
    set(gca,'XTick',[1:8:T])
    set(gca,'XTickLabel','0|8|16|24|32|40')
    ylabel('Percent');
    %if ceil(nfig/figcols)> 2;
    %xlabel('Quarter');
    %end;
end;
orient portrait;
legend(h1,['Large Responsive to Participation Gap'],['Benchmark'],['Tiny Response to Participation Gap'],'location','SouthEast');

legend boxoff;
%eval('print -depsc2 u:\modelm\searchm\figs\modv2_fig1.eps');

