%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Figure 13 from June 2014 final version 
% Considers implications of responding to the "wrong" participation gap

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

T = 40;            %Number of periods to compute impulse
PlotInternal = 1;  %Set of variables to plot, 1 for internal variables, 0 for figures in paper
PlotInLevels = 1;  %if 1, then plot in level space where steady state values in MeanVec are used. If 0, then plot as deviations from SS

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Type and size of shocks to compute
%IRFs for
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

mu1 = .92;
mu3 = .071;
psip = .975;
chi = 4;

gam_dpq= 2;
gam_xgap= 0;
gam_xgap1 = 150;
gam_egap = 0;
solv_searchn1b;

ShockSizeDom=[-.3];
ShockSizeFor=[-.7];%0.5*ShockSizeDom;
ShockLocDom = strmatch('errbtar',cellstr(endog_),'exact')-sum(eqtype_);%nendog;
ShockLocFor = strmatch('errcon',cellstr(endog_),'exact')-sum(eqtype_);%nendog;
ShockLocOS  = [ShockLocDom;ShockLocFor];
ShockSizeOS = [ShockSizeDom;ShockSizeFor];

XGAPLoc   = strmatch('xgap',cellstr(endog_),'exact');%nendog;
DPQLoc    = strmatch('dpq',cellstr(endog_),'exact');%nendog;
RSLoc     = strmatch('rs',cellstr(endog_),'exact');%nendog;
RRLoc     = strmatch('rt',cellstr(endog_),'exact');%nendog;
RRPOTLoc  = strmatch('rt_pot',cellstr(endog_),'exact');%nendog;
BTARSHKLoc = strmatch('btarshk',cellstr(endog_),'exact');%nendog;
GOVSHKLoc = strmatch('govshk',cellstr(endog_),'exact');%nendog;
PMARKSHKLoc = strmatch('techshk',cellstr(endog_),'exact');%nendog;
MPSHKLoc  = strmatch('errffr0',cellstr(endog_),'exact');%nendog;
PQLoc   = strmatch('pq',cellstr(endog_),'exact');%nendog;
EGAPLoc   = strmatch('egap',cellstr(endog_),'exact');%nendog;
LFPGAPLoc   = strmatch('lfpgap',cellstr(endog_),'exact');%nendog;
EPOTLoc  = strmatch('e_pot',cellstr(endog_),'exact');%nendog;
LFPOTLoc  = strmatch('lfp_pot',cellstr(endog_),'exact');%nendog;

%ibar_apr = ((pibar^4-1)+((1+rbar)^4-1))*100;%steady state nominal interest rate in APR
ibar_apr = 4;

if PlotInternal == 1;%Figures for internal use
   %PickVars = [XGAPLoc DPQLoc RSLoc    RRLoc RRPOTLoc GDPLoc GOVSHKLoc DEBTGLoc     TAXLLoc];%location of variables in simvar
   %ScalVec  = [1       4      4        4     4        1      shrgy     1/4          1 ];%transform variables to APR when suitable
   PickVars = [EGAPLoc LFPGAPLoc RSLoc   DPQLoc XGAPLoc LFPOTLoc];%location of variables in simvar
   ScalVec  = [-1       1      4        4     1/(1-alpha)   1 ];%transform variables to APR when suitable
   
   MeanVec  = [0       0      ibar_apr  2     0      0];%adding steady state means when suitable
   LegNames=char('Unemployment Gap','Participation Gap','Nominal Interest Rate (APR)',...
                 'Inflation','Overall Employment Gap','Potential Labor Force');
elseif PlotInternal == 0;%draw figures for the paper
   PickVars = [XGAPLoc PQLoc DPQLoc RSLoc    RRLoc RRPOTLoc EGAPLoc     LFPGAPLoc];%location of variables in simvar
   ScalVec  = [1/(1-alpha)       1      4      4        4     4        1          1 ];%transform variables to APR when suitable
   MeanVec  = [0       0      2      ibar_apr 2     2        0  0 ];%adding steady state means when suitable
   LegNames=char('Output Gap','Price Level','Inflation (APR)','Nominal Interest Rate (APR)',...
                 'Real Interest Rate (APR)','Potential Real Interest Rate (APR)',...
                 'Employment Gap','Participation Gap');
else;
   error('Must set PlotInternal to either 0 or 1');
end;

figrows = ceil(sqrt(length(PickVars)));
figcols = floor(sqrt(length(PickVars)));
if figrows*figcols<length(PickVars);
   figrows=figrows+1;
end;


zzInit = zeros(size(cofb,1),1);%vector with initial state, deviations from steady state
[simvar,zzAimOSunc]=SimulateModelAIM(cofb,scof,zzInit,ShockSizeOS,ShockLocOS,T,eqtype_,endog_,PickVars); %Function that compute impulse response functions
simvarOSunc = simvar.*(ones(T,1)*ScalVec)+ones(T,1)*MeanVec;%scaling and adding mean

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step 2: Do same thing as above
% but impose ZLB when computing the
% impulse response functions.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Step 2a: Compute shocks that are needed
%to impose the ZLB for the shocks above.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

AltIntRatePath=simvarOSunc(1:T,find(PickVars==RSLoc));%Potentially negative interest rate paths to be turned into ZLB    
save AltIntRatePath AltIntRatePath ShockLocOS ShockSizeOS zzInit;
simvarOScon=simvarOSunc;%unconstrained responses

if min(min(AltIntRatePath))<-1e-5;
   FindAltIntPathsScriptSlow;%plotting with figures
   IRpath = AltIntRatePath(1:t,:);
   [Shocks,ShockLoc] = FindShocksAIM(cofb,scof,RSLoc,IRpath,ShockLoc,ActIndicator(1:t,:),eqtype_,endog_);
   [simvarPI,zzAimPI]=SimulateModelAIM(cofb,scof,zzInit,Shocks,ShockLoc,T,eqtype_,endog_,PickVars); %Compute impulse response functions for policy interventions
   simvarPI=simvarPI.*(ones(T,1)*ScalVec);%annualizing
   simvarOScon=simvarOScon+simvarPI;%updating simvar (unconstrained response with policy intervention that respects ZLB)
   zzAimOScon = zzAimOSunc+zzAimPI;%total effects of demand shocks under ZLB
end;

%VarNames=char('FFR','FFR*','dCPI','dCPI*','GDP','GDP*');
if PlotInLevels==0;%if 0 then take away means
   simvarOSunc = simvarOSunc-ones(T,1)*MeanVec;
   simvarOScon = simvarOScon-ones(T,1)*MeanVec;
end;

simvarOSunc_xgap = simvarOSunc;
simvarOScon_xgap = simvarOScon;



% Now Compute IRFS under overall unemployment rate targeting

gam_dpq= 2;
gam_xgap= 0;
gam_xgap1 = 0;
gam_egap = 150;
solv_searchn1b;

zzInit = zeros(size(cofb,1),1);%vector with initial state, deviations from steady state
[simvar,zzAimOSunc]=SimulateModelAIM(cofb,scof,zzInit,ShockSizeOS,ShockLocOS,T,eqtype_,endog_,PickVars); %Function that compute impulse response functions
simvarOSunc = simvar.*(ones(T,1)*ScalVec)+ones(T,1)*MeanVec;%scaling and adding mean

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step 2: Do same thing as above
% but impose ZLB when computing the
% impulse response functions.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Step 2a: Compute shocks that are needed
%to impose the ZLB for the shocks above.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

AltIntRatePath=simvarOSunc(1:T,find(PickVars==RSLoc));%Potentially negative interest rate paths to be turned into ZLB    
save AltIntRatePath AltIntRatePath ShockLocOS ShockSizeOS zzInit;
simvarOScon=simvarOSunc;%unconstrained responses

if min(min(AltIntRatePath))<-1e-5;
   FindAltIntPathsScriptSlow;%plotting with figures
   IRpath = AltIntRatePath(1:t,:);
   [Shocks,ShockLoc] = FindShocksAIM(cofb,scof,RSLoc,IRpath,ShockLoc,ActIndicator(1:t,:),eqtype_,endog_);
   [simvarPI,zzAimPI]=SimulateModelAIM(cofb,scof,zzInit,Shocks,ShockLoc,T,eqtype_,endog_,PickVars); %Compute impulse response functions for policy interventions
   simvarPI=simvarPI.*(ones(T,1)*ScalVec);%annualizing
   simvarOScon=simvarOScon+simvarPI;%updating simvar (unconstrained response with policy intervention that respects ZLB)
   zzAimOScon = zzAimOSunc+zzAimPI;%total effects of demand shocks under ZLB
end;

%VarNames=char('FFR','FFR*','dCPI','dCPI*','GDP','GDP*');
if PlotInLevels==0;%if 0 then take away means
   simvarOSunc = simvarOSunc-ones(T,1)*MeanVec;
   simvarOScon = simvarOScon-ones(T,1)*MeanVec;
end;

simvarOSunc_egap = simvarOSunc;
simvarOScon_egap = simvarOScon;


close all;

TT=1:T;
titles = {['Figure 13: Misperceptions about Participation Gap']};    

for nfig=1:size(simvar,2);
    subplot(figrows,figcols,nfig)
    h1=plot(TT,simvarOScon_egap(:,nfig)',TT,simvarOScon_xgap(:,nfig)');
    set(h1,'linewidth',3,{'linestyle'},{'-';'-.'},{'color'},{'k';'b'});
    text('String',LegNames(nfig,:),'Units','normalized', ...
         'Position',[0.5 1.08],...
         'FontSize',10,'FontWeight','bold','HorizontalAlignment','center');
      
    set(gca,'XTick',[1:8:T])
    set(gca,'XTickLabel','0|8|16|24|32|40')
    ylabel('Percent');
    %if ceil(nfig/figcols)> 2;
    %xlabel('Quarter');
    %end;
end;
orient portrait;
legend(h1,['True Participation Gap (Benchmark)'],['Incorrect Participation Gap'],'location','South');

%text('String',titles,'Units','normalized', ...
 %        'Position',[-0.3 4.25],...
  %       'FontSize',13,'FontWeight','bold','HorizontalAlignment','center');
      
legend boxoff;
%eval('print -depsc2 c:\modelm\lfpr\figs\fig8.eps');
%eval('print -dpsc u:\modelm\searchm\figs\modv2_fig1.ps');

