% Parameters of Erceg-Levin Labor force participation model
% The log-linearized model is describe in section 3.3 for simplified version without habit
% Parameters that are blocked out below are set in the shock macros that
% generate Figures 7-11.


beta = .995; %discount factor
pibar = 1.005;   %inflation target in gross terms, so net inflation = pibar - 1;  
                 % note beta = .995 and pibar = 1.005 imply an annualized
                 % steady state interest rate of 4 percent
rbar = 1/beta - 1;

sigma   = 1;   % inverse intertemporal elasticity of substitution in consumption

alpha   = 0.3; % capital share, so (1-alpha) = labor share
epc = .01; % weight on taste shock in marginal utility of consumption
%chi     = 6; % inverse of Frisch elasticity of labor supply
shrgy   = .002;  % govt spending share of output in steady state
thetap = .1;   % net markup
%sigmag = 40;   % determines responsiveness of labor force participation to wages or employment
phic = .80;  % external habit persistence parameter
lfbar = 2/3;  % steady state labor force participation rate
lhbar = 1- lfbar;
ubar = .05;  % steady state unemployment rate or NAIRU
hbar = 1-ubar;  % employment rate of labor force

ybar = (hbar*lfbar)^(1-alpha);
cbar = ybar*(1-shrgy);
lambar = ((1-epc)*cbar)^(-sigma);

sigma_hat =  sigma/((1-epc)*(1-shrgy));   %inverse of elasticity of output with  
%respect to real interest rate

%psip = .975;  % price contract duration parameter

kappap = (1-beta*psip)*(1-psip)/psip;

indexp = 0.8;  % price indexation parameter

%next four parameters are used in optimal policy rule in searchn2 only that
% generates Figure 10

nub = phic/(1+phic);
nuf = 1/(1+phic);
gamb = indexp/(1+indexp*beta);
gamf = 1/(1+indexp*beta);

psi0 =  chi + alpha + (1-alpha)*sigma_hat;   % how marginal cost varies with employment
psi1 =   alpha + (1-alpha)*sigma_hat;        % how marginal cost varies with labor force participation

%Slope of the NKPC in unemployment
sparm = kappap*psi0; 

%mu1 = .92;    % persistence of labor force participation rate 
%mu3 = .071;   % sensitivity of LFP to unemployment 

% weights in optimal policy rule used in searchn2 (used only for generating
% Figure 10)

wt_dpq = 16;
wt_rs = .02;
wt_drs =  .1;
wt_xgap = 1;   
wt_egap = 0;

% weights in Taylor-style reaction function used in searchn1 (parameters
% are set in shock macros)

gam_rs=0;
%gam_dpq= 2;
%gam_xgap= 50;
%gam_egap = 0;
   
taxsub = 0;     % set the production subsidy to zero

% The shocks to government spending, consumption, the markup,
% and discount factor are specified as AR(2)'s:
% rho_j2 indicates the persistence of the growth rate
% rho_j1 determines mean reversion
% where j = g for govt, j = c for consumption taste shock, 
% j = p for the markup, and j = b for the discount shock.
% In practice we use AR(1)s, so set rho_j1 = 0 and
% let (1-rho_j1) determine the rate of decay of the AR(1)

rho_g1 = 0;      % determines how quickly government spending mean-reverts
rho_g2 = 0.25;   % persistence of growth rate of government spending shock
std_gov = (1/shrgy);    

rho_c1 = 0;
rho_c2 = 0.15;
std_con = 15/epc;

rho_p1 = 0;
rho_p2 = .1;
std_pmark = .0025;

rho_b1 = 0;
rho_b2 = 0.1;  %  1-rho_b2 is persistence of discount factor shock
std_btar = 14.5;  % determines standard deviation of discount factor shock

% The monetary policy shock is a simple AR(1)

rho_m1 = .1;
std_mon = 0.4;   


rho_t1 = 0;
rho_t2 = 1;
std_tax = 3;

 